@@ -23,6 +23,9 @@ import os
 import shutil
 
 import pytest
+import requests
+from faker import Faker
+
 from pylenium import Pylenium
 from pylenium.config import PyleniumConfig, TestCase
 from pylenium.logging import Logger
@@ -41,6 +44,18 @@ def make_dir(filepath) -> bool:
         return False
 
 
+@pytest.fixture(scope='function')
+def fake() -> Faker:
+    """ A basic instance of Faker to make test data."""
+    return Faker()
+
+
+@pytest.fixture(scope='function')
+def api():
+    """ A basic instance of Requests to make HTTP API calls. """
+    return requests
+
+
 @pytest.fixture(scope='session', autouse=True)
 def project_root() -> str:
     """ The Project (or Workspace) root as a filepath.
@@ -167,11 +182,14 @@ def pytest_runtest_makereport(item, call):
 
 
 def pytest_addoption(parser):
+    parser.addoption(
+        '--browser', action='store', default='', help='The lowercase browser name: chrome | firefox'
+    )
     parser.addoption(
         '--remote_url', action='store', default='', help='Grid URL to connect tests to.'
     )
     parser.addoption(
-        '--screenshots_on', action='store', default='', help="Should screenshots be saved? true or false"
+        '--screenshots_on', action='store', default='', help="Should screenshots be saved? true | false"
     )
     parser.addoption(
         '--pylog_level', action='store', default='', help="Set the pylog_level: 'off' | 'info' | 'debug'"
