@@ -1,6 +1,9 @@
 from typing import List, Union, Optional
 
+import requests
+from faker import Faker
 from selenium import webdriver
+from selenium.common.exceptions import ElementNotInteractableException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support.wait import WebDriverWait
 from selenium.webdriver.remote.webdriver import WebDriver
@@ -48,7 +51,8 @@ class WebDriverFactory:
         if self.config.driver.remote_url:
             return self.build_remote(
                 browser=self.config.driver.browser,
-                remote_url=self.config.driver.remote_url
+                remote_url=self.config.driver.remote_url,
+                browser_options=self.config.driver.options
             )
         if self.config.driver.browser == 'chrome':
             return self.build_chrome(self.config.driver.options)
@@ -117,6 +121,8 @@ class Pylenium:
     def __init__(self, config: PyleniumConfig, logger: Logger):
         self.config = config
         self.log = logger
+        self.fake = Faker()
+        self.request = requests
 
         # Instantiate WebDriver
         self._webdriver = WebDriverFactory(config).build_from_config()
@@ -124,7 +130,9 @@ class Pylenium:
         self.log.write(f'browserName: {caps["browserName"]}, browserVersion: {caps["browserVersion"]}, platformName: {caps["platformName"]}, session_id: {self._webdriver.session_id}')
 
         # Initial Browser Setup
-        self.wait = WebDriverWait(self._webdriver, timeout=config.driver.wait_time)
+        self.wait = WebDriverWait(self._webdriver, timeout=config.driver.wait_time,
+                                  ignored_exceptions=[ElementNotInteractableException])
+
         if config.viewport.maximize:
             self.maximize_window()
         else:
